#
# spec file for package lxcfs
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           lxcfs
Version:        2.0.8
Release:        lp150.1.9
Summary:        FUSE filesystem for LXC
License:        Apache-2.0
Group:          System/Management
Url:            http://linuxcontainers.org
Source:         https://linuxcontainers.org/downloads/%{name}/%{name}-%{version}.tar.gz
Source1:        https://linuxcontainers.org/downloads/%{name}/%{name}-%{version}.tar.gz.asc#/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  help2man
BuildRequires:  libtool
BuildRequires:  pam-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(fuse)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
LXCFS is a simple userspace filesystem designed to work around some current limitations of the Linux kernel.

Specifically, it's providing two main things

A set of files which can be bind-mounted over their /proc originals
to provide CGroup-aware values.
A cgroupfs-like tree which is container aware.
The code is pretty simple, written in C using libfuse and glib.

The main driver for this work was the need to run systemd based containers as a regular unprivileged user
while still allowing systemd inside the container to interact with cgroups.

Now with the introduction of the cgroup namespace in the Linux kernel, that part is no longer necessary
on recent kernels and focus is now on making containers feel more like a real independent system through
the proc masking feature.

%package -n pam_cgfs
Summary:        CGroup FS pam module
Group:          System/Libraries

%description -n pam_cgfs
When a user logs in, this pam module will create cgroups which the user may
administer, either for all controllers or for any controllers listed on the
command line.

%prep
%setup

%build
autoreconf --force --install
%configure --with-distro=suse
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot} %{?_smp_mflags}
install -d -m 0755 %{buildroot}%{_unitdir}
install -p -m 0644 config/init/systemd/*.service %{buildroot}%{_unitdir}/
install -d -m 0755 %{buildroot}%{_sbindir}
ln -sf service %{buildroot}%{_sbindir}/rc%{name}
install -d -m 0755 %{buildroot}%{_includedir}/%{name}
rm bindings.h
install -d -m 0755 %{buildroot}%{_localstatedir}/lib/%{name}/

# The shared library liblxcfs.so used by lxcfs is not supposed to be used by
# any other program. So we follow best practice and install it in
# /usr/lib/lxcfs. Note that lxcfs *expects* liblxcfs.so to be found in
# /usr/lib/lxcfs when it cannot find it in the lib.so path.
mkdir -p %{buildroot}/usr/lib/%{name}/
install -p -m 0755 .libs/liblxcfs.so %{buildroot}/usr/lib/%{name}/
rm -f %{buildroot}%{_libdir}/liblxcfs.so*
rm -f %{buildroot}%{_libdir}/liblxcfs.la

%pre
%service_add_pre lxcfs.service

%post
%service_add_post lxcfs.service

%preun
%service_del_preun lxcfs.service

%postun
%service_del_postun lxcfs.service

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog README COPYING
%{_sbindir}/*
%{_bindir}/*
%{_datadir}/lxc
%{_datadir}/%{name}
%{_mandir}/man1/*
%{_unitdir}/*
%dir %{_localstatedir}/lib/%{name}
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/liblxcfs.la
%{_libdir}/%{name}/liblxcfs.so

# The lxcfs executable requires liblxcfs.so be installed. It calls dlopen() to
# dynamically reload the shared library on upgrade. This is important. Do *not*
# split into a separate package and do not turn this into a versioned shared
# library! (This shared library allows lxcfs to be updated without having to
# restart it which is good when you have important system containers running!)
%dir /usr/lib/%{name}
/usr/lib/%{name}/liblxcfs.so

%files -n pam_cgfs
%defattr(-,root,root)
/%{_lib}/security/pam_cgfs.so

%changelog
* Tue Oct 31 2017 opensuse_buildservice@ojkastl.de
- update to version 2.0.8
  This is the eigth bugfix release for LXCFS 2.0. This includes the following bugfixes:
  * bindings: Add mountpoint for unified hierarchy
  * bindings: Calculate uptime via proc//stat
  * bindings: Revert virtualization of 'btime' field due to regressions in ps
  * doc: Update README
  * init: Add cgroupfs-mount to Should-Start/Stop sysvinit LSB headers
  * lib: Add common fallback dlopen for liblxcfs.so
  * lib: Fix the installation directory for liblxcfs to ${libdir}/lxcfs
  * pam: Add a 'all' option for -c
  * pam: Chown cgroup.procs file on unified hierarchy
  * pam: Report back when we find a unified hierarchy
  * tests: Fix invalid comparison
  * uptime: Fix a problem with subsequent reads
* Wed May 17 2017 opensuse_buildservice@ojkastl.de
- update to version 2.0.7
  This is the seventh bugfix release for LXCFS 2.0. This includes the following bugfixes:
  * Remove unused variable
  * Also check next variable for NULL on cg_rmdir
  * virtualize the 'btime' field of /proc/stat
  * cleanup: return false instead of NULL as bool
  * Limit memswlimit by TotalSwap
  * pam_cgfs: remove dead assignment
  * pam_cgfs: return created directly
  * pam_cgfs: make sure that **p is not NULL
  * bindings: Want space for ints? Call sizeof(int)!
  * pam_cgfs: make trim() safer
  * pam_cgfs: error out on failure in cgv2_init()
  * pam_cgfs: remove dead assignment
  * bindings: implement guest nice
  * bindings: increase reserved buffer size a little
- added signature verification
* Fri Jan 27 2017 opensuse_buildservice@ojkastl.de
- deleted patches 0001 to 00024, as they are upstream already
  - 0001-Fix-test_reload-for-lxcfs-chroot.patch
  - 0002-Virtualize-more-of-the-meminfo-fields.patch
  - 0003-pam-fix-race-in-cgroup-creation.patch
  - 0004-meminfo-don-t-show-negative-swapfree.patch
  - 0005-bindings-improve-debugging.patch
  - 0006-bindings-use-openat-fd-for-fstatat-unlinkat.patch
  - 0007-bindings-close-open-fds-on-error.patch
  - 0008-bindings-grant-access-to-var-lib-lxcfs.patch
  - 0009-bindings-enable-access-to-var-lib-lxcfs-cgroup.patch
  - 0010-bindings-allow-access-to-var-lib-lxcfs-proc.patch
  - 0011-lxcfs-bindings-show-.-and-.-dir-entries.patch
  - 0012-lxcfs-better-fs-behavior-on-var-lib-lxcfs.patch
  - 0013-bindings-non-functional-changes.patch
  - 0014-bindings-set-errno-in-pick_controller_from_path.patch
  - 0015-bindings-more-consistent-fs-behavior.patch
  - 0016-add-pld-linux-support.patch
  - 0017-don-t-use-argv-0-in-usage-output.patch
  - 0018-bindings-revert-cgroup-check.patch
  - 0019-bindings-improve-returned-errnos.patch
  - 0020-bindings-make-rmdir-behave-more-consistently.patch
  - 0021-libtool-do-not-link-lxcfs-against-liblxcfs.patch
  - 0022-bindings-lxcfs-improve-debugging.patch
  - 0023-bindings-fix-debug-macro.patch
  - 0024-bindings-restore-original-working-directory.patch
* Wed Jan 25 2017 opensuse_buildservice@ojkastl.de
- update to version 2.0.6
  This is the sixth bugfix release for LXCFS 2.0. This includes the following bugfixes:
    Fix swap values with nested cgroups
    tests: Fix run on ppc64el
    Fix wrong scanning of memory.stat
- update to version 2.0.5
  This is the fifth bugfix release for LXCFS 2.0. This includes the following bugfixes:
    Add Documentation key to systemd unit
    bindings: allow getattr on O_WRONLY files
    bindings: remove noop check
    fix Active/Inactive /proc/meminfo
    macro: add header for shared macros
    pam_cgfs: reimplement and add cgroupfs v2 support
    pam_cgfs: re-use cgroups that already belong to us
    pam_cgfs: handle cgroupfs v1 cpuset controller
    pam_cgfs: improve logging
    cgroups: handle non-existent isolcpus file
- update to version 2.0.4
  This is the fourth bugfix release for LXCFS 2.0. This includes the following bugfixes:
  Fix test_reload for lxcfs chroot
  Virtualize more of the meminfo fields
  pam: fix race in cgroup creation
  meminfo: don't show negative swapfree
  bindings: improve debugging
  bindings: use openat fd for fstatat(), unlinkat()
  bindings: close open fds on error
  bindings: grant access to /var/lib/lxcfs
  bindings: enable access to /var/lib/lxcfs/cgroup
  bindings: allow access to /var/lib/lxcfs/proc
  lxcfs, bindings: show "." and ".." dir entries
  lxcfs: better fs behavior on /var/lib/lxcfs
  bindings: non functional changes
  bindings: set errno in pick_controller_from_path()
  bindings: more consistent fs behavior
  add pld linux support
  don't use argv[0] in usage output
  bindings: revert cgroup check
  bindings: improve returned errnos
  bindings: make rmdir behave more consistently
  libtool: do not link lxcfs against liblxcfs
  bindings, lxcfs: improve debugging
  bindings: fix debug macro
  autotools: add -avoid-version
  bindings: restore original working directory
  bindings: add function to check fs type
  bindings: agnostic naming
  bindings: use chroot() on ramfs
  bindings: fix type weirdness with statfs f_type
  bindings: make pivot_enter() contain all its code
* Wed Aug 31 2016 cbrauner@suse.de
- update lxcfs to 2.0.3
- add 0001-Fix-test_reload-for-lxcfs-chroot.patch
- add 0002-Virtualize-more-of-the-meminfo-fields.patch
- add 0003-pam-fix-race-in-cgroup-creation.patch
- add 0004-meminfo-don-t-show-negative-swapfree.patch
- add 0005-bindings-improve-debugging.patch
- add 0006-bindings-use-openat-fd-for-fstatat-unlinkat.patch
- add 0007-bindings-close-open-fds-on-error.patch
- add 0008-bindings-grant-access-to-var-lib-lxcfs.patch
- add 0009-bindings-enable-access-to-var-lib-lxcfs-cgroup.patch
- add 0010-bindings-allow-access-to-var-lib-lxcfs-proc.patch
- add 0011-lxcfs-bindings-show-.-and-.-dir-entries.patch
- add 0012-lxcfs-better-fs-behavior-on-var-lib-lxcfs.patch
- add 0013-bindings-non-functional-changes.patch
- add 0014-bindings-set-errno-in-pick_controller_from_path.patch
- add 0015-bindings-more-consistent-fs-behavior.patch
- add 0016-add-pld-linux-support.patch
- add 0017-don-t-use-argv-0-in-usage-output.patch
- add 0018-bindings-revert-cgroup-check.patch
- add 0019-bindings-improve-returned-errnos.patch
- add 0020-bindings-make-rmdir-behave-more-consistently.patch
- add 0021-libtool-do-not-link-lxcfs-against-liblxcfs.patch
- add 0022-bindings-lxcfs-improve-debugging.patch
- add 0023-bindings-fix-debug-macro.patch
- add 0024-bindings-restore-original-working-directory.patch
* Wed Aug 31 2016 cbrauner@suse.de
- remove 0001-skip-empty-entries-under-proc-self-cgroup.patch
* Sat Jul 23 2016 cbrauner@suse.com
- remove explicit Provides for pam_cgfs subpackage
* Mon Jul 11 2016 cbrauner@suse.de
- install pam_cgfs.so with the pam_cgfs subpackage
* Sun Jul 10 2016 cbrauner@suse.com
- add 0001-skip-empty-entries-under-proc-self-cgroup.patch
* Thu Jul  7 2016 cbrauner@suse.de
- Remove lxcfs-devel.
- Install shared library liblxcfs.so into /usr/lib/lxcfs as it is not supposed
  to be used by any other program.
* Thu Jul  7 2016 cbrauner@suse.de
- rename devel package from liblxcfs-devel to lxcfs-devel
* Thu Jul  7 2016 cbrauner@suse.de
- make sure that lxcfs install the shared library liblxcfs.so:
  The lxcfs executable requires liblxcfs.so be installed. It calls dlopen() to
  dynamically reload the shared library on upgrade. This is important. Do *not*
  split into a separate package and do not turn this into a versioned shared
  library! (This shared library allows lxcfs to be updated without having to
  restart running containers!)
* Thu Jul  7 2016 cbrauner@suse.de
- add lxcfs package
